==> knative-model-6.8.1-sources.jar: io/fabric8/knative/internal/eventing/pkg/apis/duck/v1/DeliverySpecFluent.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DeliverySpecFluent<A extends DeliverySpecFluent<A>> extends BaseFluent<A>{
  public DeliverySpecFluent() {
  }
  public DeliverySpecFluent(DeliverySpec instance) {
    instance = (instance != null ? instance : new DeliverySpec());

    if (instance != null) {
      this.withBackoffDelay(instance.getBackoffDelay());
      this.withBackoffPolicy(instance.getBackoffPolicy());
      this.withDeadLetterSink(instance.getDeadLetterSink());
      this.withRetry(instance.getRetry());
      this.withRetryAfterMax(instance.getRetryAfterMax());
      this.withTimeout(instance.getTimeout());
      this.withBackoffDelay(instance.getBackoffDelay());
      this.withBackoffPolicy(instance.getBackoffPolicy());
      this.withDeadLetterSink(instance.getDeadLetterSink());
      this.withRetry(instance.getRetry());
      this.withRetryAfterMax(instance.getRetryAfterMax());
      this.withTimeout(instance.getTimeout());
    }
  }
  private String backoffDelay;
  private String backoffPolicy;
  private DestinationBuilder deadLetterSink;
  private Integer retry;
  private String retryAfterMax;
  private String timeout;
  public String getBackoffDelay() {
    return this.backoffDelay;
  }
  public A withBackoffDelay(String backoffDelay) {
    this.backoffDelay=backoffDelay; return (A) this;
  }
  public boolean hasBackoffDelay() {
    return this.backoffDelay != null;
  }
  public String getBackoffPolicy() {
    return this.backoffPolicy;
  }
  public A withBackoffPolicy(String backoffPolicy) {
    this.backoffPolicy=backoffPolicy; return (A) this;
  }
  public boolean hasBackoffPolicy() {
    return this.backoffPolicy != null;
  }
  public Destination buildDeadLetterSink() {
    return this.deadLetterSink!=null ?this.deadLetterSink.build():null;
  }
  public A withDeadLetterSink(Destination deadLetterSink) {
    _visitables.get("deadLetterSink").remove(this.deadLetterSink);
    if (deadLetterSink!=null){ this.deadLetterSink= new DestinationBuilder(deadLetterSink); _visitables.get("deadLetterSink").add(this.deadLetterSink);} else { this.deadLetterSink = null; _visitables.get("deadLetterSink").remove(this.deadLetterSink); } return (A) this;
  }
  public boolean hasDeadLetterSink() {
    return this.deadLetterSink != null;
  }
  public DeadLetterSinkNested<A> withNewDeadLetterSink() {
    return new DeadLetterSinkNested(null);
  }
  public DeadLetterSinkNested<A> withNewDeadLetterSinkLike(Destination item) {
    return new DeadLetterSinkNested(item);
  }
  public DeadLetterSinkNested<A> editDeadLetterSink() {
    return withNewDeadLetterSinkLike(java.util.Optional.ofNullable(buildDeadLetterSink()).orElse(null));
  }
  public DeadLetterSinkNested<A> editOrNewDeadLetterSink() {
    return withNewDeadLetterSinkLike(java.util.Optional.ofNullable(buildDeadLetterSink()).orElse(new DestinationBuilder().build()));
  }
  public DeadLetterSinkNested<A> editOrNewDeadLetterSinkLike(Destination item) {
    return withNewDeadLetterSinkLike(java.util.Optional.ofNullable(buildDeadLetterSink()).orElse(item));
  }
  public Integer getRetry() {
    return this.retry;
  }
  public A withRetry(Integer retry) {
    this.retry=retry; return (A) this;
  }
  public boolean hasRetry() {
    return this.retry != null;
  }
  public String getRetryAfterMax() {
    return this.retryAfterMax;
  }
  public A withRetryAfterMax(String retryAfterMax) {
    this.retryAfterMax=retryAfterMax; return (A) this;
  }
  public boolean hasRetryAfterMax() {
    return this.retryAfterMax != null;
  }
  public String getTimeout() {
    return this.timeout;
  }
  public A withTimeout(String timeout) {
    this.timeout=timeout; return (A) this;
  }
  public boolean hasTimeout() {
    return this.timeout != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeliverySpecFluent that = (DeliverySpecFluent) o;
    if (!java.util.Objects.equals(backoffDelay, that.backoffDelay)) return false;

    if (!java.util.Objects.equals(backoffPolicy, that.backoffPolicy)) return false;

    if (!java.util.Objects.equals(deadLetterSink, that.deadLetterSink)) return false;

    if (!java.util.Objects.equals(retry, that.retry)) return false;

    if (!java.util.Objects.equals(retryAfterMax, that.retryAfterMax)) return false;

    if (!java.util.Objects.equals(timeout, that.timeout)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(backoffDelay,  backoffPolicy,  deadLetterSink,  retry,  retryAfterMax,  timeout,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (backoffDelay != null) { sb.append("backoffDelay:"); sb.append(backoffDelay + ","); }
    if (backoffPolicy != null) { sb.append("backoffPolicy:"); sb.append(backoffPolicy + ","); }
    if (deadLetterSink != null) { sb.append("deadLetterSink:"); sb.append(deadLetterSink + ","); }
    if (retry != null) { sb.append("retry:"); sb.append(retry + ","); }
    if (retryAfterMax != null) { sb.append("retryAfterMax:"); sb.append(retryAfterMax + ","); }
    if (timeout != null) { sb.append("timeout:"); sb.append(timeout); }
    sb.append("}");
    return sb.toString();
  }
  public class DeadLetterSinkNested<N> extends DestinationFluent<DeadLetterSinkNested<N>> implements Nested<N>{
    DeadLetterSinkNested(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    DestinationBuilder builder;
    public N and() {
      return (N) DeliverySpecFluent.this.withDeadLetterSink(builder.build());
    }
    public N endDeadLetterSink() {
      return and();
    }
    
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/eventing/pkg/apis/duck/v1/DeliverySpecFluent.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class DeliverySpecFluent<A extends DeliverySpecFluent<A>> extends BaseFluent<A>{
  public DeliverySpecFluent() {
  }
  
  public DeliverySpecFluent(DeliverySpec instance) {
    this.copyInstance(instance);
  }
  private String backoffDelay;
  private String backoffPolicy;
  private DestinationBuilder deadLetterSink;
  private Integer retry;
  private String retryAfterMax;
  private String timeout;
  
  protected void copyInstance(DeliverySpec instance) {
    instance = (instance != null ? instance : new DeliverySpec());
  
    if (instance != null) {
        this.withBackoffDelay(instance.getBackoffDelay());
        this.withBackoffPolicy(instance.getBackoffPolicy());
        this.withDeadLetterSink(instance.getDeadLetterSink());
        this.withRetry(instance.getRetry());
        this.withRetryAfterMax(instance.getRetryAfterMax());
        this.withTimeout(instance.getTimeout());
        this.withBackoffDelay(instance.getBackoffDelay());
        this.withBackoffPolicy(instance.getBackoffPolicy());
        this.withDeadLetterSink(instance.getDeadLetterSink());
        this.withRetry(instance.getRetry());
        this.withRetryAfterMax(instance.getRetryAfterMax());
        this.withTimeout(instance.getTimeout());
      }
  }
  
  public String getBackoffDelay() {
    return this.backoffDelay;
  }
  
  public A withBackoffDelay(String backoffDelay) {
    this.backoffDelay=backoffDelay; return (A) this;
  }
  
  public boolean hasBackoffDelay() {
    return this.backoffDelay != null;
  }
  
  public String getBackoffPolicy() {
    return this.backoffPolicy;
  }
  
  public A withBackoffPolicy(String backoffPolicy) {
    this.backoffPolicy=backoffPolicy; return (A) this;
  }
  
  public boolean hasBackoffPolicy() {
    return this.backoffPolicy != null;
  }
  
  public Destination buildDeadLetterSink() {
    return this.deadLetterSink!=null ?this.deadLetterSink.build():null;
  }
  
  public A withDeadLetterSink(Destination deadLetterSink) {
    _visitables.get("deadLetterSink").remove(this.deadLetterSink);
    if (deadLetterSink!=null){ this.deadLetterSink= new DestinationBuilder(deadLetterSink); _visitables.get("deadLetterSink").add(this.deadLetterSink);} else { this.deadLetterSink = null; _visitables.get("deadLetterSink").remove(this.deadLetterSink); } return (A) this;
  }
  
  public boolean hasDeadLetterSink() {
    return this.deadLetterSink != null;
  }
  
  public DeadLetterSinkNested<A> withNewDeadLetterSink() {
    return new DeadLetterSinkNested(null);
  }
  
  public DeadLetterSinkNested<A> withNewDeadLetterSinkLike(Destination item) {
    return new DeadLetterSinkNested(item);
  }
  
  public DeadLetterSinkNested<A> editDeadLetterSink() {
    return withNewDeadLetterSinkLike(java.util.Optional.ofNullable(buildDeadLetterSink()).orElse(null));
  }
  
  public DeadLetterSinkNested<A> editOrNewDeadLetterSink() {
    return withNewDeadLetterSinkLike(java.util.Optional.ofNullable(buildDeadLetterSink()).orElse(new DestinationBuilder().build()));
  }
  
  public DeadLetterSinkNested<A> editOrNewDeadLetterSinkLike(Destination item) {
    return withNewDeadLetterSinkLike(java.util.Optional.ofNullable(buildDeadLetterSink()).orElse(item));
  }
  
  public Integer getRetry() {
    return this.retry;
  }
  
  public A withRetry(Integer retry) {
    this.retry=retry; return (A) this;
  }
  
  public boolean hasRetry() {
    return this.retry != null;
  }
  
  public String getRetryAfterMax() {
    return this.retryAfterMax;
  }
  
  public A withRetryAfterMax(String retryAfterMax) {
    this.retryAfterMax=retryAfterMax; return (A) this;
  }
  
  public boolean hasRetryAfterMax() {
    return this.retryAfterMax != null;
  }
  
  public String getTimeout() {
    return this.timeout;
  }
  
  public A withTimeout(String timeout) {
    this.timeout=timeout; return (A) this;
  }
  
  public boolean hasTimeout() {
    return this.timeout != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeliverySpecFluent that = (DeliverySpecFluent) o;
    if (!java.util.Objects.equals(backoffDelay, that.backoffDelay)) return false;
  
    if (!java.util.Objects.equals(backoffPolicy, that.backoffPolicy)) return false;
  
    if (!java.util.Objects.equals(deadLetterSink, that.deadLetterSink)) return false;
  
    if (!java.util.Objects.equals(retry, that.retry)) return false;
  
    if (!java.util.Objects.equals(retryAfterMax, that.retryAfterMax)) return false;
  
    if (!java.util.Objects.equals(timeout, that.timeout)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(backoffDelay,  backoffPolicy,  deadLetterSink,  retry,  retryAfterMax,  timeout,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (backoffDelay != null) { sb.append("backoffDelay:"); sb.append(backoffDelay + ","); }
    if (backoffPolicy != null) { sb.append("backoffPolicy:"); sb.append(backoffPolicy + ","); }
    if (deadLetterSink != null) { sb.append("deadLetterSink:"); sb.append(deadLetterSink + ","); }
    if (retry != null) { sb.append("retry:"); sb.append(retry + ","); }
    if (retryAfterMax != null) { sb.append("retryAfterMax:"); sb.append(retryAfterMax + ","); }
    if (timeout != null) { sb.append("timeout:"); sb.append(timeout); }
    sb.append("}");
    return sb.toString();
  }
  public class DeadLetterSinkNested<N> extends DestinationFluent<DeadLetterSinkNested<N>> implements Nested<N>{
    DeadLetterSinkNested(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    DestinationBuilder builder;
    
    public N and() {
      return (N) DeliverySpecFluent.this.withDeadLetterSink(builder.build());
    }
    
    public N endDeadLetterSink() {
      return and();
    }
    
  
  }

}
